"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CmdUtils = void 0;
const InstanceChecker_1 = require("../util/InstanceChecker");
exports.CmdUtils = {
    loadDataSource(dataSourceFilePath) {
        let dataSourceFileExports;
        try {
            dataSourceFileExports = require(dataSourceFilePath);
        }
        catch (err) {
            throw new Error(`Invalid file path given: "${dataSourceFilePath}". File must contain a TypeScript / JavaScript code and export a DataSource instance.`);
        }
        if (!dataSourceFileExports ||
            typeof dataSourceFileExports !== "object") {
            throw new Error(`Given data source file must contain export of a DataSource instance`);
        }
        const dataSourceExports = [];
        for (let fileExport in dataSourceFileExports) {
            if (InstanceChecker_1.InstanceChecker.isDataSource(dataSourceFileExports[fileExport])) {
                dataSourceExports.push(dataSourceFileExports[fileExport]);
            }
        }
        if (dataSourceExports.length === 0) {
            throw new Error(`Given data source file must contain export of a DataSource instance`);
        }
        if (dataSourceExports.length > 1) {
            throw new Error(`Given data source file must contain only one export of DataSource instance`);
        }
        return dataSourceExports[0];
    },
};

//# sourceMappingURL=CmdUtils.js.map
